@@ -12,18 +12,16 @@ class ApiDto:
         """
         pass
 
-    def to_json(self, api=False):
+    def to_json(self):
         """
         transform current object into a dumpable dict compatible with JSON format.
-        :param api: set to True if desired format is for Web API or by default return .py SDK format.
         :return: dumpable dict.
         """
         pass
 
-    def from_json(self, obj, api=True):
+    def from_json(self, obj):
         """
         load the object from a dict originating of a JSON format.
         :param obj: object to load information from.
-        :param api: set to True if desired format is from Web API or by default from .py SDK format.
         """
         pass
