@@ -53,6 +53,7 @@ class DataFrameToolkit:
             df['Timestamp'] = df['Timestamp'].apply(lambda _: datetime.datetime.strptime(_, "%Y-%m-%d-%H-%M-%S-%f"))
 
         df = df.set_index('Timestamp')
+        df.rename_axis("sensorId", axis="columns", inplace=True)
 
         return df
 
@@ -67,7 +68,8 @@ class DataFrameToolkit:
         :return: panda Dataframe
         """
         df = pandas.DataFrame.from_dict(json, orient='columns')
-        df = df.set_index('timestamp')
+        df = df.set_index('Timestamp')
+        df.rename_axis("sensorId", axis="columns", inplace=True)
         return df
 
     @classmethod
@@ -80,7 +82,9 @@ class DataFrameToolkit:
         :param df: panda Dataframe to convert.
         :return: dictionary representing JSON compatible dataframe.
         """
-        df_json = {"timestamp": list(df.index)}
+        df_json = {
+            "Timestamp": list(df.index)
+        }
         for col in list(df.columns):
             if col != 'Timestamp':
                 df_json[col] = list(df[col].values.astype(float))
